@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 ## no critic
-our $VERSION = '2.22';
+our $VERSION = '2.23';
 $VERSION = eval $VERSION;
 ## use critic
 
@@ -126,7 +126,7 @@ sub _find_zone {
 
 sub _punycode_segments {
     my ( $domain_segments, $zone ) = @_;
-    if ( not $zone or $zone !~ /^de$/ ) {
+    if ( not $zone or $zone !~ /^(?:de|fr|pm|re|tf|wf|yt)$/ ) {
         my $puny_encoded = [];
         foreach my $segment ( @{$domain_segments} ) {
             croak
